git: 1e95a9a41c21 - main - mld6query: Fix typos

From: Warner Losh <imp_at_FreeBSD.org>
Date: Fri, 02 Jun 2023 02:34:10 UTC
The branch main has been updated by imp:

URL: https://cgit.FreeBSD.org/src/commit/?id=1e95a9a41c21fee3197bf3676e1f3a0c5075d82f

commit 1e95a9a41c21fee3197bf3676e1f3a0c5075d82f
Author:     Elyes Haouas <ehaouas@noos.fr>
AuthorDate: 2023-06-01 23:41:34 +0000
Commit:     Warner Losh <imp@FreeBSD.org>
CommitDate: 2023-06-02 02:33:41 +0000

    mld6query: Fix typos
    
    Signed-off-by: Elyes Haouas <ehaouas@noos.fr>
    Reviewed by: imp
    Pull Request: https://github.com/freebsd/freebsd-src/pull/653
---
 usr.sbin/mld6query/mld6.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/usr.sbin/mld6query/mld6.c b/usr.sbin/mld6query/mld6.c
index 2506308702d4..e722f91eb990 100644
--- a/usr.sbin/mld6query/mld6.c
+++ b/usr.sbin/mld6query/mld6.c
@@ -107,7 +107,7 @@ main(int argc, char *argv[])
 		switch (ch) {
 		case 'd':
 			if (type != MLD_LISTENER_QUERY) {
-				printf("Can not specifiy -d with -r\n");
+				printf("Can not specify -d with -r\n");
 				return 1;
 			}
 			type = MLD_LISTENER_DONE;
@@ -117,7 +117,7 @@ main(int argc, char *argv[])
 			break;
 		case 'r':
 			if (type != MLD_LISTENER_QUERY) {
-				printf("Can not specifiy -r with -d\n");
+				printf("Can not specify -r with -d\n");
 				return 1;
 			}
 			type = MLD_LISTENER_REPORT;
@@ -140,7 +140,7 @@ main(int argc, char *argv[])
 	if (argc == 2 && inet_pton(AF_INET6, argv[1], &maddr) != 1)
 		usage();
 	if (type != MLD_LISTENER_QUERY && qaddr != &maddr) {
-		printf("Can not specifiy -g with -d or -r\n");
+		printf("Can not specify -g with -d or -r\n");
 		return 1;
 	}
 
@@ -270,7 +270,7 @@ make_msg(int index, struct in6_addr *addr, u_int type, struct in6_addr *qaddr)
 	pi = (struct in6_pktinfo *)CMSG_DATA(cmsgp);
 	pi->ipi6_ifindex = index;
 	memcpy(&pi->ipi6_addr, &src, sizeof(pi->ipi6_addr));
 	/* specifiy to insert router alert option in a hop-by-hop opt hdr. */
 	cmsgp = CMSG_NXTHDR(&m, cmsgp);
 	cmsgp->cmsg_len = CMSG_LEN(hbhlen);
 	cmsgp->cmsg_level = IPPROTO_IPV6;
@@ -270,7 +270,7 @@ make_msg(int index, struct in6_addr *addr, u_int type, struct in6_addr *qaddr)
 	pi->ipi6_ifindex = index;
 	memcpy(&pi->ipi6_addr, &src, sizeof(pi->ipi6_addr));
-	/* specifiy to insert router alert option in a hop-by-hop opt hdr. */
+	/* specify to insert router alert option in a hop-by-hop opt hdr. */
 	cmsgp = CMSG_NXTHDR(&m, cmsgp);
 	cmsgp->cmsg_len = CMSG_LEN(hbhlen);